==> allure-report-data-1.4.14-sources.jar: ru/yandex/qatools/allure/data/AllureDefect.java <==

package ru.yandex.qatools.allure.data;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlType;
import ru.yandex.qatools.allure.model.Status;


/**
 * <p>Java class for allure-defect complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="allure-defect"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="title" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="status" type="{urn:data.allure.qatools.yandex.ru}status"/&gt;
 *         &lt;element name="defects" type="{urn:data.allure.qatools.yandex.ru}defects"/&gt;
 *       &lt;/all&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "allure-defect", propOrder = {

})
public class AllureDefect {

    @XmlElement(required = true)
    protected String title;
    @XmlElement(required = true)
    protected Status status;
    @XmlElementWrapper(name = "defects", required = true)
    @XmlElement(name = "defect-item")
    protected List<DefectItem> defects;

    /**
     * Gets the value of the title property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTitle() {
        return title;
    }

    /**
     * Sets the value of the title property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTitle(String value) {
        this.title = value;
    }

    /**
     * Gets the value of the status property.
     * 
     * @return
     *     possible object is
     *     {@link Status }
     *     
     */
    public Status getStatus() {
        return status;
    }

    /**
     * Sets the value of the status property.
     * 
     * @param value
     *     allowed object is
     *     {@link Status }
     *     
     */
    public void setStatus(Status value) {
        this.status = value;
    }

    public List<DefectItem> getDefects() {
        if (defects == null) {
            defects = new ArrayList<DefectItem>();
        }
        return defects;
    }

    public void setDefects(List<DefectItem> defects) {
        this.defects = defects;
    }

}

==> allure-report-data-1.5.3-sources.jar: ru/yandex/qatools/allure/data/AllureDefect.java <==

package ru.yandex.qatools.allure.data;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlType;
import ru.yandex.qatools.allure.model.Status;


/**
 * <p>Java class for allure-defect complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="allure-defect">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;all>
 *         &lt;element name="title" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="status" type="{urn:data.allure.qatools.yandex.ru}status"/>
 *         &lt;element name="defects" type="{urn:data.allure.qatools.yandex.ru}defects"/>
 *       &lt;/all>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "allure-defect", propOrder = {

})
public class AllureDefect {

    @XmlElement(required = true)
    protected String title;
    @XmlElement(required = true)
    protected Status status;
    @XmlElementWrapper(name = "defects", required = true)
    @XmlElement(name = "defect-item")
    protected List<DefectItem> defects;

    /**
     * Gets the value of the title property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTitle() {
        return title;
    }

    /**
     * Sets the value of the title property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTitle(String value) {
        this.title = value;
    }

    /**
     * Gets the value of the status property.
     * 
     * @return
     *     possible object is
     *     {@link Status }
     *     
     */
    public Status getStatus() {
        return status;
    }

    /**
     * Sets the value of the status property.
     * 
     * @param value
     *     allowed object is
     *     {@link Status }
     *     
     */
    public void setStatus(Status value) {
        this.status = value;
    }

    public List<DefectItem> getDefects() {
        if (defects == null) {
            defects = new ArrayList<DefectItem>();
        }
        return defects;
    }

    public void setDefects(List<DefectItem> defects) {
        this.defects = defects;
    }

}
